@@ -47,15 +47,15 @@ class CGSmartImage extends CGExtensions
   function LazyLoadFrontend() { return FALSE; }
   function GetName() { return get_class($this); }
   function GetFriendlyName() { return $this->Lang('friendlyname');  }
-  function GetVersion() { return '1.12'; }
-  function MinimumCMSVersion() { return '1.11.7'; }
+  function GetVersion() { return '1.13'; }
+  function MinimumCMSVersion() { return '1.11.8'; }
   function GetDependencies() { return array('CGExtensions'=>'1.37.2');   }
   function GetAuthor() { return 'calguy1000'; }
   function GetAuthorEmail() { return 'calguy1000@gmail.com'; }
-  function IsPluginModule() { return true; }
+  function IsPluginModule() { return TRUE; }
   function GetAdminSection() { return 'extensions'; }
-  function HandlesEvents () { return false; }
-  function HasAdmin() { return true; }
+  function HandlesEvents () { return FALSE; }
+  function HasAdmin() { return TRUE; }
   function VisibleToAdminUser() { return $this->CheckPermission('Modify Site Preferences'); }
   function AllowAutoInstall() { return FALSE; }
   function AllowAutoUpgrade() { return FALSE; }
@@ -230,11 +230,12 @@ class CGSmartImage extends CGExtensions
   {
     $config = cmsms()->GetConfig();
     $cache_path = $this->GetPreference('cache_path', cms_join_path('uploads', '_'.$this->GetName()));
-    $dir = cms_join_path($config['root_path'], $cache_path);
-    
-    $p1 = realpath($dir);
+    $tp1 = $cache_path;
+    if( !is_dir($tp1) ) $tp1 = $config['root_path'].'/'.$tp1;
+    $p1 = realpath($tp1);
     $p2 = realpath($config['root_path']);
     if( $p1 == $p2 || !startswith($p1,$p2) ) throw new Exception($this->Lang('error_cachepath_invalid'));
+    $dir = $tp1;
 
     $age_days = (int)$this->GetPreference('cache_age');
     if( $age_days <= 0 ) throw new Exception($this->Lang('error_invalid_age'));
