@@ -45,9 +45,11 @@ try {
     // validate the cache path.
     $cache_path = trim($params['cache_path']);
     if( !$cache_path ) throw new Exception($this->Lang('error_cachepath_invalid'));
-    $p1 = realpath($cache_path);
+    $tp1 = $cache_path;
+    if( !is_dir($tp1) ) $tp1 = $config['root_path'].'/'.$tp1;
+    $p1 = realpath($tp1);
     $p2 = realpath($config['root_path']);
-    if( !startswith($p1,$p2) ) throw new Exception($this->Lang('error_cachepath_invalid'));
+    if( $p1 == $p2 || !startswith($p1,$p2) ) throw new Exception($this->Lang('error_cachepath_invalid'));
 
     $this->SetPreference('croptofit_default_loc',trim($params['croptofit_default_loc']));
     $this->SetPreference('cache_age',(int)$params['cache_age']);
@@ -55,6 +57,7 @@ try {
     $this->SetPreference('image_url_prefix',trim($params['image_url_prefix']));
     $this->SetPreference('silent',(int)$params['silent']);
     $this->SetPreference('image_url_hascachedir',(isset($params['image_url_hascachedir']))?(int)$params['image_url_hascachedir']:0);
+    $this->SetPreference('checkmemory',(int)$params['checkmemory']);
     $this->SetMessage($this->Lang('msg_prefsupdated'));
   }
   else if( isset($params['clear_now']) ) {
@@ -67,11 +70,14 @@ try {
   else if( isset($params['clear_all']) ) {
     // just nuke the cache directory completely.
     $cache_path = $this->GetPreference('cache_path', cms_join_path('uploads', '_'.$this->GetName()));
-    $dir = cms_join_path($config['root_path'], $cache_path);
+    $dir = $cache_path;
+    if( !startswith($dir,'/') ) $dir = $config['root_path'].'/'.$cache_path;
     $p1 = realpath($dir);
     $p2 = realpath($config['root_path']);
-    if( !startwith($p1,$p2) || $p1 == $p2 ) throw new Exception($this->Lang('error_cachepath_invalid'));
+    if( !startswith($p1,$p2) || $p1 == $p2 ) throw new Exception($this->Lang('error_cachepath_invalid'));
     cge_dir::recursive_rmdir($dir);
+    mkdir($dir);
+    @touch($dir.'/index.html');
     $this->SetMessage($this->Lang('msg_cacheremoved'));
     audit('',$this->GetName(),'All cached files removed');
   }
