@@ -10,6 +10,7 @@ $lang['ask_clear_image_cache'] = 'Are you sure you want to remove ALL files from
 $lang['clear_all'] = 'Clear All Files';
 $lang['clear_now'] = 'Clear Now';
 $lang['cache_path'] = 'Cache Path';
+$lang['check_memory'] = 'Do preemptive memory check';
 
 # D
 $lang['delete'] = 'Delete';
@@ -23,7 +24,9 @@ $lang['enable_responsive'] = 'Enable Responsive Images';
 $lang['error_alias_duplicatename_atrow'] = 'Duplicate alias name specified for alias at row %d';
 $lang['error_alias_noname_atrow'] = 'No name specified for alias at row %d';
 $lang['error_alias_nooptions_atrow'] = 'No options specified for alias at row %d';
+$lang['error_cachepath_invalid'] = 'The cache path specified is invalid';
 $lang['error_invalid_age'] = 'Age preference invalid... No operation performed';
+$lang['error_insufficientmemory'] = 'PHP does not have enough memory to process this image';
 $lang['error_missingparam'] = 'A required parameter was missing or invalid: %s';
 $lang['error_invalidparam'] = 'Invalid parameter in call: %s';
 $lang['error_srcnotfound'] = 'Could not find a file at: %s';
@@ -40,6 +43,7 @@ $lang['general'] = 'General';
 
 # I
 $lang['info_aliases'] = 'Aliaes can be used via the alias1 through alias5 options on the CGSmartImage tag to combine numerous frequently used options';
+$lang['info_check_memory'] = 'If enabled, the system will attempt to estimate memory needed for an image transformation, and will fail if insufficient available memory is detected';
 $lang['info_croptofit_default_loc'] = 'Specify the default location from which to &quot;crop to fit&quot; this will effect all crop to fit operations unless the location parameter on the filter_croptofit attribute overrides it.  Default location is &quot;center&quot;';
 $lang['info_responsive'] = 'If enabled, CGSmartImage will attempt to detect the maximum resolution of the requesting device and automatically rescale the image so that under no circumstances can the output image be too large for the display.  This assists in performance when developing mobile websites.';
 $lang['info_responsive_breakpoints'] = '<strong>Experimental:</strong> If specified, and a mobile device is detected the breakpoints will be used to determine the maximum largest edge for the resulting image.  Specify a list of comma separated increasing integers <em>(i.e: 200,400,600,800)</em>. The device capabilties will be used to find the closest matching breakpoint value.  The image will be resized so that its largest edge is at that value without upscaling.  Aspect ratio will be maintained.';
@@ -59,7 +63,7 @@ $lang['max_cache_age'] = 'Maximum Cache File Age (days)';
 $lang['moddescription'] = 'A smart image tag generation module for CMSMS';
 $lang['msg_aliases_updated'] = 'Aliases Updated';
 $lang['msg_cachecleaned'] = 'Cache directory cleaned. %d files removed';
-$lang['msg_cacheremoved'] = 'Cache Removed';
+$lang['msg_cacheremoved'] = 'Cache directory completely cleaned';
 $lang['msg_prefsupdated'] = 'Preferences Updated';
 
 # N
