@@ -103,11 +103,19 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
       $new_h = (int) $this->_dest_h;
       $new_w = (int) ceil($this->_dest_h * $src_ratio);
     }
-    else if( $src_ratio < $dest_ratio ) {
+    else {
+      //else if( $src_ratio < $dest_ratio ) {
       $new_w = (int) $this->_dest_w;
       $new_h = (int) ceil($this->_dest_w / $src_ratio );
     }
 
+    // if src and new measurements are identical at this time
+    // we revert to a simple resize.
+    if( $new_w == $src['width'] && $new_h == $src['height'] ) {
+      $filter = new CGImage_Resize_Filter(array('width'=>$this->_dest_w,'height'=>$this->_dest_h,'resample'=>1));
+      return $filter->transform($src);
+    }
+
     // get the transparent color of the source image.
     $tc = imagecolorat($src['rsrc'],0,$src['height']-1);
     $tr = $tg = $tb = 0; $ta = 127;
@@ -188,7 +196,7 @@ class CGImage_Croptofit_Filter extends CGImageFilterBase
     imagecolortransparent($_dest['rsrc'],$transparent2);
     imagefill($_dest['rsrc'], 0, 0, $transparent2);
 
-    // copy the temp iamge into the dest image.
+    // copy the temp image into the dest image.
     imagealphablending($_dest['rsrc'],TRUE);  
     $res = imagecopy($_dest['rsrc'],$tmp_rsrc,0,0,$x0,$y0,$new_w,$new_h);
     if( $res === FALSE ) throw new Exception('Croptofit - stage 2 - failed');
