@@ -46,10 +46,8 @@ class cgsi_utils
     if( !$aliases ) {
       $mod = cms_utils::get_module('CGSmartImage');
       $tmp = $mod->GetPreference('aliases');
-      if( !$tmp ) 
-	$aliases = 'FALSE';
-      else
-	$aliases = unserialize($tmp);
+      $aliases = 'FALSE';
+      if( $tmp ) $aliases = unserialize($tmp);
     }
     if( is_array($aliases) ) {
       $keys = array_keys($aliases);
@@ -240,12 +238,8 @@ class cgsi_utils
 	}
 	elseif( startswith($key,'src') && $key != 'src' ) {
 	  // handle src1 through src99 arguments.
-	  if( !isset($new_params['src']) ) {
-	    $new_params['src'] = '';
-	  }
-	  if( !empty($new_params['src']) && !endswith($new_params['src'],'/') ) {
-	    $new_params['src'] .= '/';
-	  }
+	  if( !isset($new_params['src']) ) $new_params['src'] = '';
+	  if( !empty($new_params['src']) && !endswith($new_params['src'],'/') ) $new_params['src'] .= '/';
 	  $new_params['src'] .= $value;
 	  continue;
 	}
@@ -400,9 +394,12 @@ class cgsi_utils
       }
       else {
 	$srcimgsize = array('width'=>$tmp[0],'height'=>$tmp[1]);
-	$memory_needed = round( $tmp[0] * $tmp[1] * (isset($tmp['bits'])?$tmp['bits']:8) 
-				* (isset($tmp['channels'])?$tmp['channels']/8:3) + 65535 );
-	if( !cge_utils::have_enough_memory($memory_needed) ) throw new Exception($mod->Lang('error_insufficientmemory'));
+	$memory_needed = round( $tmp[0] * $tmp[1] 
+				* (isset($tmp['bits'])?$tmp['bits']:8) 
+				* (isset($tmp['channels'])?$tmp['channels']:3) / 8 + 65535 );
+	if( $mod->GetPreference('checkmemory',1) && !cge_utils::have_enough_memory($memory_needed) ) {
+	  throw new Exception($mod->Lang('error_insufficientmemory')+': '.(int)($memory_needed/1024)+'k');
+	}
       }
 
       // are we automagically rotating.
@@ -504,8 +501,7 @@ class cgsi_utils
 
       // now do some intelligence, and see if the width, and height arguments passed in
       // match the image size... if not, and max_width/height aren't already smaller... add a filter.
-      if( $no_width_height == 0 &&
-	  ($outp['width'] > 0 || $outp['height'] > 0) && $opp['noautoscale'] == 0 ) {
+      if( $no_width_height == 0 && ($outp['width'] > 0 || $outp['height'] > 0) && $opp['noautoscale'] == 0 ) {
 	if( $outp['width'] != $srcimgsize['width'] || $outp['height'] != $srcimgsize['height'] ) {
 	  // we wanna display the file at a different dimenion.
 	  $args = '';
@@ -542,7 +538,6 @@ class cgsi_utils
       // if we have max width and/or height... add a filter at the end
       // to make sure that our output never exceeds those max values.
       if( ($opp['max_width'] > 0 || $opp['max_height'] > 0) && $opp['noautoscale'] == 0 ) {
-
 	// if we have breakpoints, use find the closest one
 	$args = '';
 	$filter = '';
@@ -599,11 +594,7 @@ class cgsi_utils
       //
       // end of smartness stuff... now begin the work
       //
-
-      if( count(array_keys($opp['filters'])) ) {
-	// we're doing some kind of magic to the image.
-	$want_transform = 1;
-      }
+      if( count(array_keys($opp['filters'])) ) $want_transform = 1; // we're doing some kind of magic to the image.
 
       if( $want_transform ) {
 	// calculate our destination name and url.
@@ -672,6 +663,19 @@ class cgsi_utils
 	}
       } // if
 
+      // now, we have a cached filename ... need to get its dimensions.
+      // and make sure that we're never outputting anything bigger than the cached dimensions
+      // unless noauto is set
+      if( $opp['noauto'] == 0 ) {
+	$tmp = getimagesize($dest_fname);
+	if( !is_array($tmp) || count($tmp) < 2 ) throw new Exception($mod->Lang('error_destnotfound',$dest_fname));
+	$t_width = $tmp[0]; $t_height = $tmp[1];
+	if( ($outp['width'] && $t_width < $outp['width']) || ($outp['height'] && $t_height < $outp['height']) ) {
+	  $outp['width'] = $t_width;
+	  $outp['height'] = $t_height;
+	}
+      }
+      
       // at this point, we're ready to handle building the tag.
       if( $opp['nobcache'] ) $dest_url .= '?x='.time();      
 
@@ -737,7 +741,6 @@ class cgsi_utils
       }
     }
     catch( Exception $e ) {
-      die($e->GetMessage());
       $outp['error'] = $e->GetMessage();
     }
 
@@ -751,12 +754,8 @@ class cgsi_utils
     if( !$content ) return;
     $max_width = -1;
     $max_height = -1;
-    if( isset($params['max_height']) ) {
-      $max_height = max(0,(int)$params['max_height']);
-    }
-    if( isset($params['max_width']) ) {
-      $max_width = max(0,(int)$params['max_width']);
-    }
+    if( isset($params['max_height']) ) $max_height = max(0,(int)$params['max_height']);
+    if( isset($params['max_width']) ) $max_width = max(0,(int)$params['max_width']);
 
     $did_modify = FALSE;
     $mod = cms_utils::get_module('CGSmartImage');
@@ -764,9 +763,7 @@ class cgsi_utils
     $dom = new CGDomDocument();
     $dom->strictErrorChecking = FALSE;
     $dom->validateOnParse = FALSE;
-    if( function_exists('mb_convert_encoding') ) {
-      $content = mb_convert_encoding($content, 'HTML-ENTITIES', 'UTF-8');
-    }
+    if( function_exists('mb_convert_encoding') ) $content = mb_convert_encoding($content, 'HTML-ENTITIES', 'UTF-8');
     $dom->loadHTML($content);
 
     $imgs = $dom->GetElementsByTagName('img');
@@ -776,28 +773,30 @@ class cgsi_utils
 	$sxe = simplexml_import_dom($node);
 
 	$parms = $params;
+	$process = true;
 	foreach( $sxe->attributes() as $name => $value ) {
 	  $value = (string)$value;
 	  if( $value == '' ) continue;
 
 	  switch( $name ) {
 	  case 'width':
-	    if( $max_width > 0 ) {
-	      $value = min($max_width,(int)$value);
-	    }
+	    if( $max_width > 0 ) $value = min($max_width,(int)$value);
 	    break;
 
 	  case 'height':
-	    if( $max_height > 0 ) {
-	      $value = min($max_height,(int)$value);
-	    }
+	    if( $max_height > 0 ) $value = min($max_height,(int)$value);
+	    break;
+
+	  case 'class':
+	    $words = explode(' ',$value);
+	    if( in_array('nocgsi',$words) ) $process = false;
 	    break;
 	  }
 	  $parms[$name] = $value;
 	}
 
+	if( !$process ) continue; // found a reason not do to anything with this image.
 	if( !isset($parms['src']) ) continue;
-
 	if( startswith($parms['src'],'data:') ) continue;   // already embedded, can't do anything.
 
 	$parms['notag'] = 1;
@@ -815,7 +814,7 @@ class cgsi_utils
 	    break;
 	  }
 	}
-      }
+      } // for each image
     }
 
     // get the contents.
@@ -839,9 +838,7 @@ class cgsi_utils
 
   public static function get_device_capabilities()
   {
-    if( is_array(self::$_device_data) && isset(self::$_device_data['width']) ) {
-      return self::$_device_data;
-    }
+    if( is_array(self::$_device_data) && isset(self::$_device_data['width']) ) return self::$_device_data;
 
     if( !isset($_SERVER['HTTP_USER_AGENT']) ) return;
     $browser = cge_utils::get_browser();
@@ -855,9 +852,7 @@ class cgsi_utils
     $data = array();
     if( $handler->exists($ckey) ) {
       $rawdat = $handler->get($ckey);
-      if( $rawdat ) {
-	$data = unserialize($rawdat);
-      }
+      if( $rawdat ) $data = unserialize($rawdat);
     }
     $ukey = md5($agent);
     if( isset($data[$ukey]) ) {
@@ -872,15 +867,9 @@ class cgsi_utils
 
     // instantiate the class and do the request
     $client_class = 'cgsi_DeviceAtlasPersonal_client';
-    if( !class_exists($client_class) ) {
-      // no client class found.
-      return;
-    }
+    if( !class_exists($client_class) ) return; // no client class found.
     $client_obj = new $client_class($agent);
-    if( !is_object($client_obj) ) {
-      // no client class possible.
-      return;
-    }
+    if( !is_object($client_obj) ) return; // no client class possible.
     $res = $client_obj->get_device_resolution();
     if( !is_array($res) ) return;
 
@@ -902,7 +891,7 @@ class cgsi_utils
 
   public static function get_transparent_color(CGImageBase $img)
   {
-   if( $img['transparent'] != '' ) return $img['transparent'];
+    if( $img['transparent'] != '' ) return $img['transparent'];
   }
 
   public static function find_unused_color(CGImageBase $img)
@@ -919,9 +908,7 @@ class cgsi_utils
       $found++;
     }
 
-    if( $found == 50 ) {
-      audit('','CGSmartImage','No unused color found');
-    }
+    if( $found == 50 ) audit('','CGSmartImage','No unused color found');
     return array($r,$g,$b);
   }
 
